.TH "g4_create_source_cfg_file" "3" "1" "Polhemus" "G4SrcCfgLib"
.SH "NAME"
\fBg4_create_source_cfg_file\fR \- Create a Polhemus G4 Source Configuration File
.SH "SYNOPSIS"
#include "G4SrcCfgIncl.h"
.br 


int \fBg4_create_source_cfg_file\fR(int \fIpos_units\fR,
.br 
					int \fIorientation_units\fR,
.br 
					LPG4_SRC_DATA_STRUCT \fIpds\fR,
.br 
					const char* \fIfilename\fR)
.SH "DESCRIPTION"
This function is called to create a new G4 source configuration file named \fIfilename\fR.  It will use the data in the \fIpds\fR structure to populate the file.  The data will be in the units specified in the \fIpos_units\fR and \fIorientation_units\fR parameters.
.SH "RETURN VALUES"
Zero for success, non\-zero for failure
.SH "PARAMETERS"
\fIpos_units\fR:  the desired units for source position data.  Use \fBG4_SRC_CFG_INCH\fR,\fBG4_SRC_CFG_FOOT\fR,\fBG4_SRC_CFG_CM\fR, or \fBG4_SRC_CFG_METER\fR
.br 

\fIorientation_units\fR: the desired units for orienation.  Use \fBG4_SRC_CFG_EULER_DEGREE\fR, \fBG4_SRC_CFG_EULER_RADIAN\fR, or \fBG4_SRC_CFG_QUATERNION\fR
.br 

\fIpds\fR: Pointer to struct that contains data to write to file.
.br 

\fIfilename\fR: File to create.
.SH "EXAMPLE"
#include "G4SrcCfgIncl.h"
.br 

G4_SRC_DATA_STRUCT sd;
.br 
const char* filename="SomeSourceCfgFile.g4c";
.br 
const char* newfilename="NewPosSourceCfgFile.g4c";
.br 
int rc=g4_read_source_cfg_file(G4_SRC_CFG_INCH,G4_SRC_CFG_EULER_DEGREE,&sd,filename);
.br 

if(rc)
.br 
	return some error;

.br 
// change position for source 0 to 10,20,30
.br 
sd.pos_ori[0][0]=10.0f;
.br 
sd.pos_ori[0][1]=20.0f;
.br 
sd.pos_ori[0][2]=30.0f;
.br 


// create new file
.br 
rc=g4_create_source_cfg_file(G4_SRC_CFG_INCH,G4_SRC_CFG_EULER_DEGREE,&sd,newfilename);
.br 

if (rc)
.br 
	return some_error;
.SH "AUTHOR"
James C. Farr <jimfarr@polhemus.com>
.SH "SEE ALSO"
\fBG4SrcCfgLib\fR(3), \fBG4_SRC_DATA_STRUCT\fR(3), \fBg4_read_source_cfg_file\fR(3), \fBg4_get_freq_sn_from_attr\fR(3)
